You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by fs...@apache.org on 2019/08/29 20:03:50 UTC

[jmeter] branch master updated (a6824ae -> 81ba16c)

This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git.


    from a6824ae  notify all waiting threads when result is computed
     new 6e858d8  Use string formats in log messages and add a missing U to URL
     new 82aa4e2  Fix: typos
     new ff79a53  Change function variable name displayJMeterPropterties by displayJMeterProperties
     new 039a56e  Change function variable name displayJMeterPropterties with displayJMeterProperties
     new 8c6da20  Refactor: Replace rowIndx variable name with rowIndex
     new 0988c06  Rename variables
     new 30ae6d7  Rename variable: replace savee by save
     new 9b0c656  Rename variable: replace ignoreResorces by ignoreResources
     new c73951d  Rename function name: Replace getConfiguredDatatSource() by getConfiguredDataSource()
     new 93fb4a62 Rename variable: replace newlist by newList
     new 68df1dc  Use a longer name for method variable
     new 38283aa  Follow the java convention for parameter names
     new 81ba16c  Spacepolice

The 13 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 .../jmeter/extractor/DebugPostProcessor.java       |  4 +--
 .../org/apache/jmeter/sampler/DebugSampler.java    |  4 +--
 .../jmeter/timers/ConstantThroughputTimer.java     |  4 +--
 .../src/main/java/org/apache/jmeter/JMeter.java    |  2 +-
 .../apache/jmeter/config/gui/ArgumentsPanel.java   |  8 ++---
 .../control/gui/TestFragmentControllerGui.java     |  2 +-
 .../org/apache/jmeter/engine/JMeterEngine.java     |  2 +-
 .../java/org/apache/jmeter/gui/action/Load.java    |  2 +-
 .../org/apache/jmeter/gui/util/FilePanelEntry.java |  2 +-
 .../apache/jmeter/gui/util/JLabeledRadioI18N.java  | 40 +++++++++++-----------
 .../org/apache/jmeter/save/CSVSaveService.java     |  8 ++---
 .../java/org/apache/jmeter/util/JMeterUtils.java   | 10 +++---
 .../org/apache/jorphan/collections/HashTree.java   |  6 ++--
 .../jmeter/protocol/http/control/Cookie.java       |  6 ++--
 .../http/control/gui/HttpMirrorControlGui.java     |  2 +-
 .../http/gui/action/ParseCurlCommandAction.java    |  2 +-
 .../protocol/http/parser/RegexpHTMLParser.java     | 16 ++++-----
 .../jmeter/protocol/http/proxy/HttpReplyHdr.java   |  4 +--
 .../protocol/http/proxy/gui/ProxyControlGui.java   |  2 +-
 .../jmeter/protocol/http/sampler/HTTPHC4Impl.java  |  2 +-
 .../jmeter/protocol/http/sampler/PostWriter.java   |  2 +-
 .../protocol/jdbc/config/DataSourceElement.java    |  6 ++--
 .../jmeter/protocol/jms/sampler/JMSProperties.java |  4 +--
 .../protocol/jms/sampler/PublisherSampler.java     |  2 +-
 .../protocol/java/control/gui/ClassFilter.java     |  8 ++---
 xdocs/changes.xml                                  |  2 +-
 26 files changed, 74 insertions(+), 78 deletions(-)


[jmeter] 07/13: Rename variable: replace savee by save

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 30ae6d7bc59eb9e751c047d298b31dbc99b7caaa
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:12:19 2019 +0100

    Rename variable: replace savee by save
    
    Part of #482 on github
---
 src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java b/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java
index b48c1f1..87925c2 100644
--- a/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java
+++ b/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java
@@ -1104,14 +1104,14 @@ public final class CSVSaveService {
     public static void saveSampleResult(SampleEvent event, PrintWriter out) {
         SampleSaveConfiguration saveConfiguration = event.getResult().getSaveConfig();
         String delimiter = saveConfiguration.getDelimiter();
-        String savee = resultToDelimitedString(event, event.getResult(), saveConfiguration, delimiter);
-        out.println(savee);
+        String save = resultToDelimitedString(event, event.getResult(), saveConfiguration, delimiter);
+        out.println(save);
 
         if(saveConfiguration.saveSubresults()) {
             SampleResult result = event.getResult();
             for (SampleResult subResult : result.getSubResults()) {
-                savee = resultToDelimitedString(event, subResult, saveConfiguration, delimiter);
-                out.println(savee);
+                save = resultToDelimitedString(event, subResult, saveConfiguration, delimiter);
+                out.println(save);
             }
         }
     }


[jmeter] 12/13: Follow the java convention for parameter names

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 38283aacf211cb5aeb86b1327efe0b00a499696a
Author: Felix Schumacher <fe...@internetallee.de>
AuthorDate: Thu Aug 29 21:42:27 2019 +0200

    Follow the java convention for parameter names
    
    Part of #482 on github
---
 .../org/apache/jmeter/gui/util/JLabeledRadioI18N.java    | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java b/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java
index 87925c2..c7a5bb5 100644
--- a/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java
+++ b/src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java
@@ -1104,14 +1104,14 @@ public final class CSVSaveService {
     public static void saveSampleResult(SampleEvent event, PrintWriter out) {
         SampleSaveConfiguration saveConfiguration = event.getResult().getSaveConfig();
         String delimiter = saveConfiguration.getDelimiter();
-        String save = resultToDelimitedString(event, event.getResult(), saveConfiguration, delimiter);
-        out.println(save);
+        String formattedResult = resultToDelimitedString(event, event.getResult(), saveConfiguration, delimiter);
+        out.println(formattedResult);
 
         if(saveConfiguration.saveSubresults()) {
             SampleResult result = event.getResult();
             for (SampleResult subResult : result.getSubResults()) {
-                save = resultToDelimitedString(event, subResult, saveConfiguration, delimiter);
-                out.println(save);
+                formattedResult = resultToDelimitedString(event, subResult, saveConfiguration, delimiter);
+                out.println(formattedResult);
             }
         }
     }


[jmeter] 02/13: Fix: typos

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 82aa4e2af4ad4434ef3d632982756ceb05284e6e
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 17:57:26 2019 +0100

    Fix: typos
    
    Part of #482 on github
---
 .../main/java/org/apache/jmeter/timers/ConstantThroughputTimer.java | 4 ++--
 src/core/src/main/java/org/apache/jmeter/JMeter.java                | 2 +-
 .../org/apache/jmeter/control/gui/TestFragmentControllerGui.java    | 2 +-
 src/core/src/main/java/org/apache/jmeter/engine/JMeterEngine.java   | 2 +-
 src/core/src/main/java/org/apache/jmeter/gui/action/Load.java       | 2 +-
 .../src/main/java/org/apache/jmeter/gui/util/FilePanelEntry.java    | 2 +-
 .../src/main/java/org/apache/jorphan/collections/HashTree.java      | 6 +++---
 .../main/java/org/apache/jmeter/protocol/http/control/Cookie.java   | 6 +++---
 .../jmeter/protocol/http/control/gui/HttpMirrorControlGui.java      | 2 +-
 .../jmeter/protocol/http/gui/action/ParseCurlCommandAction.java     | 2 +-
 .../java/org/apache/jmeter/protocol/http/proxy/HttpReplyHdr.java    | 4 ++--
 .../org/apache/jmeter/protocol/http/proxy/gui/ProxyControlGui.java  | 2 +-
 .../java/org/apache/jmeter/protocol/http/sampler/HTTPHC4Impl.java   | 2 +-
 .../java/org/apache/jmeter/protocol/http/sampler/PostWriter.java    | 2 +-
 .../java/org/apache/jmeter/protocol/jms/sampler/JMSProperties.java  | 4 ++--
 .../org/apache/jmeter/protocol/jms/sampler/PublisherSampler.java    | 2 +-
 16 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/src/components/src/main/java/org/apache/jmeter/timers/ConstantThroughputTimer.java b/src/components/src/main/java/org/apache/jmeter/timers/ConstantThroughputTimer.java
index b62f069..e1b40f3 100644
--- a/src/components/src/main/java/org/apache/jmeter/timers/ConstantThroughputTimer.java
+++ b/src/components/src/main/java/org/apache/jmeter/timers/ConstantThroughputTimer.java
@@ -39,7 +39,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * This class implements a constant throughput timer. A Constant Throughtput
+ * This class implements a constant throughput timer. A Constant Throughput
  * Timer paces the samplers under its influence so that the total number of
  * samples per unit of time approaches a given constant as much as possible.
  *
@@ -98,7 +98,7 @@ public class ConstantThroughputTimer extends AbstractTestElement implements Time
     //For calculating throughput across all threads
     private static final ThroughputInfo allThreadsInfo = new ThroughputInfo();
 
-    //For holding the ThrougputInfo objects for all ThreadGroups. Keyed by AbstractThreadGroup objects
+    //For holding the ThroughputInfo objects for all ThreadGroups. Keyed by AbstractThreadGroup objects
     private static final ConcurrentMap<AbstractThreadGroup, ThroughputInfo> threadGroupsInfoMap =
             new ConcurrentHashMap<>();
 
diff --git a/src/core/src/main/java/org/apache/jmeter/JMeter.java b/src/core/src/main/java/org/apache/jmeter/JMeter.java
index 1a26d7b..9526629 100644
--- a/src/core/src/main/java/org/apache/jmeter/JMeter.java
+++ b/src/core/src/main/java/org/apache/jmeter/JMeter.java
@@ -1124,7 +1124,7 @@ public class JMeter implements JMeterPlugin {
      * </ul>
      * THIS IS INTERNAL JMETER API and should be used with care
      * @param tree The {@link HashTree} to convert
-     * @param cloneAtEnd  boolean wether we clone the tree at end
+     * @param cloneAtEnd  boolean whether we clone the tree at end
      * @return HashTree the output {@link HashTree} to use
      */
     public static HashTree convertSubTree(HashTree tree, boolean cloneAtEnd) {
diff --git a/src/core/src/main/java/org/apache/jmeter/control/gui/TestFragmentControllerGui.java b/src/core/src/main/java/org/apache/jmeter/control/gui/TestFragmentControllerGui.java
index b5acf26..d5813a3 100644
--- a/src/core/src/main/java/org/apache/jmeter/control/gui/TestFragmentControllerGui.java
+++ b/src/core/src/main/java/org/apache/jmeter/control/gui/TestFragmentControllerGui.java
@@ -87,7 +87,7 @@ public class TestFragmentControllerGui extends AbstractControllerGui {
     }
 
     /**
-     * Redefined to remove change parent and inserrt parent menu
+     * Redefined to remove change parent and insert parent menu
      * @see org.apache.jmeter.control.gui.AbstractControllerGui#createPopupMenu()
      */
     @Override
diff --git a/src/core/src/main/java/org/apache/jmeter/engine/JMeterEngine.java b/src/core/src/main/java/org/apache/jmeter/engine/JMeterEngine.java
index a6c99cc..5f7aeda 100644
--- a/src/core/src/main/java/org/apache/jmeter/engine/JMeterEngine.java
+++ b/src/core/src/main/java/org/apache/jmeter/engine/JMeterEngine.java
@@ -46,7 +46,7 @@ public interface JMeterEngine {
     }
     /**
      *
-     * @param now boolean that tell wether stop is immediate (interrupt) or not (wait for current sample end)
+     * @param now boolean that tell whether stop is immediate (interrupt) or not (wait for current sample end)
      */
     void stopTest(boolean now);
 
diff --git a/src/core/src/main/java/org/apache/jmeter/gui/action/Load.java b/src/core/src/main/java/org/apache/jmeter/gui/action/Load.java
index 1f1a617..676df24 100644
--- a/src/core/src/main/java/org/apache/jmeter/gui/action/Load.java
+++ b/src/core/src/main/java/org/apache/jmeter/gui/action/Load.java
@@ -202,7 +202,7 @@ public class Load extends AbstractActionWithNoRunningTest {
         guiInstance.getMainFrame().getTree().setSelectionPath(
                 new TreePath(((JMeterTreeNode) newTree.getArray()[0]).getPath()));
         final HashTree subTree = guiInstance.getCurrentSubTree();
-        // Send different event wether we are merging a test plan into another test plan,
+        // Send different event whether we are merging a test plan into another test plan,
         // or loading a testplan from scratch
         ActionEvent actionEvent =
             new ActionEvent(subTree.get(subTree.getArray()[subTree.size() - 1]), id,
diff --git a/src/core/src/main/java/org/apache/jmeter/gui/util/FilePanelEntry.java b/src/core/src/main/java/org/apache/jmeter/gui/util/FilePanelEntry.java
index 6ab8568..b54397e 100644
--- a/src/core/src/main/java/org/apache/jmeter/gui/util/FilePanelEntry.java
+++ b/src/core/src/main/java/org/apache/jmeter/gui/util/FilePanelEntry.java
@@ -55,7 +55,7 @@ public class FilePanelEntry extends HorizontalPanel implements ActionListener {
 
     private boolean onlyDirectories = false;
 
-    // Mainly needed for unit test Serialisable tests
+    // Mainly needed for unit test Serializable tests
     public FilePanelEntry() {
         this(JMeterUtils.getResString("file_visualizer_filename")); //$NON-NLS-1$
     }
diff --git a/src/jorphan/src/main/java/org/apache/jorphan/collections/HashTree.java b/src/jorphan/src/main/java/org/apache/jorphan/collections/HashTree.java
index 3e48849..6d9a0b7 100644
--- a/src/jorphan/src/main/java/org/apache/jorphan/collections/HashTree.java
+++ b/src/jorphan/src/main/java/org/apache/jorphan/collections/HashTree.java
@@ -744,7 +744,7 @@ public class HashTree implements Serializable, Map<Object, HashTree>, Cloneable
     }
 
     /**
-     * Recurses down into the HashTree stucture using each subsequent key in the
+     * Recurses down into the HashTree structure using each subsequent key in the
      * array of keys, and returns the Set of keys of the HashTree object at the
      * end of the recursion. If the HashTree represented a file system, this
      * would be like getting a list of all the files in a directory specified by
@@ -762,7 +762,7 @@ public class HashTree implements Serializable, Map<Object, HashTree>, Cloneable
     }
 
     /**
-     * Recurses down into the HashTree stucture using each subsequent key in the
+     * Recurses down into the HashTree structure using each subsequent key in the
      * List of keys, and returns the Set of keys of the HashTree object at the
      * end of the recursion. If the HashTree represented a file system, this
      * would be like getting a list of all the files in a directory specified by
@@ -823,7 +823,7 @@ public class HashTree implements Serializable, Map<Object, HashTree>, Cloneable
     }
 
     /**
-     * Recurses down into the HashTree stucture using each subsequent key in the
+     * Recurses down into the HashTree structure using each subsequent key in the
      * array of keys, and returns an array of keys of the HashTree object at the
      * end of the recursion. If the HashTree represented a file system, this
      * would be like getting a list of all the files in a directory specified by
diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/Cookie.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/Cookie.java
index 06de6d5..03c5399 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/Cookie.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/Cookie.java
@@ -54,14 +54,14 @@ public class Cookie extends AbstractTestElement implements Serializable {
     private static final int DEFAULT_VERSION = 1;
 
     /**
-     * create the coookie
+     * create the cookie
      */
     public Cookie() {
         this("","","","",false,0,false,false);
     }
 
     /**
-     * create the coookie
+     * create the cookie
      * @param name name of the cookie
      * @param value value of the cookie
      * @param domain domain for which the cookie is valid
@@ -75,7 +75,7 @@ public class Cookie extends AbstractTestElement implements Serializable {
     }
 
     /**
-     * create the coookie
+     * create the cookie
      * @param name name of the cookie
      * @param value value of the cookie
      * @param domain domain for which the cookie is valid
diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/gui/HttpMirrorControlGui.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/gui/HttpMirrorControlGui.java
index 26c7586..15347fb 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/gui/HttpMirrorControlGui.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/control/gui/HttpMirrorControlGui.java
@@ -217,7 +217,7 @@ public class HttpMirrorControlGui extends LogicControllerGui
     }
 
     /**
-     * Redefined to remove change parent and inserrt parent menu
+     * Redefined to remove change parent and insert parent menu
      * @see org.apache.jmeter.control.gui.AbstractControllerGui#createPopupMenu()
      */
     @Override
diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/gui/action/ParseCurlCommandAction.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/gui/action/ParseCurlCommandAction.java
index b8a3489..70bc844 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/gui/action/ParseCurlCommandAction.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/gui/action/ParseCurlCommandAction.java
@@ -240,7 +240,7 @@ public class ParseCurlCommandAction extends AbstractAction implements MenuCreato
         guiPackage.getMainFrame().getTree()
                 .setSelectionPath(new TreePath(((JMeterTreeNode) newTree.getArray()[0]).getPath()));
         final HashTree subTree = guiPackage.getCurrentSubTree();
-        // Send different event wether we are merging a test plan into another test
+        // Send different event whether we are merging a test plan into another test
         // plan,
         // or loading a testplan from scratch
         ActionEvent actionEvent = new ActionEvent(subTree.get(subTree.getArray()[subTree.size() - 1]), e.getID(),
diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/HttpReplyHdr.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/HttpReplyHdr.java
index 0881df8..5f03f92 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/HttpReplyHdr.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/HttpReplyHdr.java
@@ -177,7 +177,7 @@ public final class HttpReplyHdr {
      * @return The header in a string;
      */
     public static String formMethod() {
-        return formError("303 Method unseported", "Method unseported");
+        return formError("303 Method unsupported", "Method unsupported");
     }
 
     /**
@@ -195,7 +195,7 @@ public final class HttpReplyHdr {
      * @return The header in a string;
      */
     public static String formUnauthorized() {
-        return formError("401 Unathorized", "Unathorized use of this service");
+        return formError("401 Unauthorized", "Unauthorized use of this service");
     }
 
     /**
diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/gui/ProxyControlGui.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/gui/ProxyControlGui.java
index cc32e01..b17deec 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/gui/ProxyControlGui.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/proxy/gui/ProxyControlGui.java
@@ -1218,7 +1218,7 @@ public class ProxyControlGui extends LogicControllerGui implements JMeterGUIComp
     }
 
     /**
-     * Redefined to remove change parent and inserrt parent menu
+     * Redefined to remove change parent and insert parent menu
      * @see org.apache.jmeter.control.gui.AbstractControllerGui#createPopupMenu()
      */
     @Override
diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/HTTPHC4Impl.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/HTTPHC4Impl.java
index e12b463..caec2f4 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/HTTPHC4Impl.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/HTTPHC4Impl.java
@@ -1533,7 +1533,7 @@ public class HTTPHC4Impl extends HTTPHCAbstractImpl {
             Header contentTypeHeader = entityEnclosingRequest.getFirstHeader(HTTPConstants.HEADER_CONTENT_TYPE);
             boolean hasContentTypeHeader = contentTypeHeader != null && contentTypeHeader.getValue() != null && contentTypeHeader.getValue().length() > 0;
             // If there are no arguments, we can send a file as the body of the request
-            // TODO: needs a multiple file upload scenerio
+            // TODO: needs a multiple file upload scenario
             if(!hasArguments() && getSendFileAsPostBody()) {
                 // If getSendFileAsPostBody returned true, it's sure that file is not null
                 HTTPFileArg file = files[0];
diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/PostWriter.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/PostWriter.java
index 3232105..dfe9b81 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/PostWriter.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/sampler/PostWriter.java
@@ -295,7 +295,7 @@ public class PostWriter {
                     // Allow the mimetype of the file to control the content type
                     // This is not obvious in GUI if you are not uploading any files,
                     // but just sending the content of nameless parameters
-                    // TODO: needs a multiple file upload scenerio
+                    // TODO: needs a multiple file upload scenario
                     if(!hasContentTypeHeader) {
                         HTTPFileArg file = files.length > 0? files[0] : null;
                         if(file != null && file.getMimeType() != null && file.getMimeType().length() > 0) {
diff --git a/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/JMSProperties.java b/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/JMSProperties.java
index 53ed871..86ffe5d 100644
--- a/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/JMSProperties.java
+++ b/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/JMSProperties.java
@@ -44,14 +44,14 @@ public class JMSProperties extends AbstractTestElement implements Serializable {
     public static final String JMS_PROPERTIES = "JMSProperties.properties"; //$NON-NLS-1$
 
     /**
-     * Create a new JmsPropertys object with no JmsProperties
+     * Create a new JmsProperties object with no JmsProperties
      */
     public JMSProperties() {
         setProperty(new CollectionProperty(JMS_PROPERTIES, new ArrayList<JMSProperty>()));
     }
 
     /**
-     * Get the JmsPropertiess.
+     * Get the JmsProperties.
      *
      * @return the JmsProperties
      */
diff --git a/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/PublisherSampler.java b/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/PublisherSampler.java
index da6c321..044d6ce 100644
--- a/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/PublisherSampler.java
+++ b/src/protocol/jms/src/main/java/org/apache/jmeter/protocol/jms/sampler/PublisherSampler.java
@@ -264,7 +264,7 @@ public class PublisherSampler extends BaseJMSSampler implements TestStateListene
     }
 
     /**
-     * Fills in result and decide wether to reconnect or not depending on
+     * Fills in result and decide whether to reconnect or not depending on
      * checkForReconnect and underlying {@link JMSException#getErrorCode()}
      *
      * @param result


[jmeter] 10/13: Rename variable: replace newlist by newList

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 93fb4a626223ab41339ad12b3b90cf3175f57c1b
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:17:43 2019 +0100

    Rename variable: replace newlist by newList
    
    Part of #482 on github
---
 .../org/apache/jmeter/protocol/java/control/gui/ClassFilter.java  | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/protocol/junit/src/main/java/org/apache/jmeter/protocol/java/control/gui/ClassFilter.java b/src/protocol/junit/src/main/java/org/apache/jmeter/protocol/java/control/gui/ClassFilter.java
index 4905466..cbdf2f5 100644
--- a/src/protocol/junit/src/main/java/org/apache/jmeter/protocol/java/control/gui/ClassFilter.java
+++ b/src/protocol/junit/src/main/java/org/apache/jmeter/protocol/java/control/gui/ClassFilter.java
@@ -45,14 +45,14 @@ class ClassFilter {
     }
 
     String[] filterArray(List<String> items) {
-        List<String> newlist = new ArrayList<>();
+        List<String> newList = new ArrayList<>();
         for (String item : items) {
             if (include(item)) {
-                newlist.add(item);
+                newList.add(item);
             }
         }
-        if (!newlist.isEmpty()) {
-            return newlist.toArray(ArrayUtils.EMPTY_STRING_ARRAY);
+        if (!newList.isEmpty()) {
+            return newList.toArray(ArrayUtils.EMPTY_STRING_ARRAY);
         } else {
             return ArrayUtils.EMPTY_STRING_ARRAY;
         }


[jmeter] 13/13: Spacepolice

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 81ba16c2213c6af78a388a7c94a11474d20348a6
Author: Felix Schumacher <fe...@internetallee.de>
AuthorDate: Thu Aug 29 21:44:25 2019 +0200

    Spacepolice
    
    Closes #482 on github
---
 src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java | 4 ++--
 xdocs/changes.xml                                              | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java b/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java
index a4483f9..d3aecfe 100644
--- a/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java
+++ b/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java
@@ -527,11 +527,11 @@ public class JMeterUtils implements UnitTestManager {
                 }
                 resString = defaultValue;
             }
-            if (ignoreResources ){ // Special mode for debugging resource handling
+            if (ignoreResources) { // Special mode for debugging resource handling
                 return "["+key+"]";
             }
         } catch (MissingResourceException mre) { // NOSONAR We handle correctly exception
-            if (ignoreResources ){ // Special mode for debugging resource handling
+            if (ignoreResources) { // Special mode for debugging resource handling
                 return "[?"+key+"?]";
             }
             if(defaultValue == null) {
diff --git a/xdocs/changes.xml b/xdocs/changes.xml
index c06a068..130b8ea 100644
--- a/xdocs/changes.xml
+++ b/xdocs/changes.xml
@@ -205,7 +205,7 @@ to view the last release notes of version 5.1.1.
     <li><bug>63394</bug>JMeter should fail with non-zero when test execution fails (due to missing test plan or other reason). Contributed by Ubik Load Pack (support at ubikloadpack.com)</li>
     <li><bug>63464</bug>image/svg+xml is wrongly considered as binary</li>
     <li><bug>63490</bug>At end of scheduler duration lots of Samplers gets executed at the same time</li>
-    <li><pr>480</pr>Fix a few typos in comments and log messages. Based on patch by Anass Benomar (anassbenomar at gmail.com)</li>
+    <li><pr>480</pr><pr>482</pr>Fix a few typos in comments and log messages. Based on patch by Anass Benomar (anassbenomar at gmail.com)</li>
 </ul>
 
  <!--  =================== Thanks =================== -->


[jmeter] 05/13: Refactor: Replace rowIndx variable name with rowIndex

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 8c6da205595d7a0763b9e28adb5a2dfad3cf2e14
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:05:18 2019 +0100

    Refactor: Replace rowIndx variable name with rowIndex
    
    Part of #482 on github
---
 .../main/java/org/apache/jmeter/config/gui/ArgumentsPanel.java    | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/protocol/jdbc/src/main/java/org/apache/jmeter/protocol/jdbc/config/DataSourceElement.java b/src/protocol/jdbc/src/main/java/org/apache/jmeter/protocol/jdbc/config/DataSourceElement.java
index 3872f6b..0711f0c 100644
--- a/src/protocol/jdbc/src/main/java/org/apache/jmeter/protocol/jdbc/config/DataSourceElement.java
+++ b/src/protocol/jdbc/src/main/java/org/apache/jmeter/protocol/jdbc/config/DataSourceElement.java
@@ -337,7 +337,7 @@ public class DataSourceElement extends AbstractTestElement
          * @return String connection information
          */
         public String getConnectionInfo() {
-            BasicDataSource dsc = getConfiguredDatatSource();
+            BasicDataSource dsc = getConfiguredDataSource();
             StringBuilder builder = new StringBuilder(100);
             builder.append("shared:").append(sharedDSC != null)
                 .append(", driver:").append(dsc.getDriverClassName())
@@ -351,7 +351,7 @@ public class DataSourceElement extends AbstractTestElement
          * @throws SQLException if database access error occurred
          */
         public Connection getConnection() throws SQLException {
-            BasicDataSource dsc = getConfiguredDatatSource();
+            BasicDataSource dsc = getConfiguredDataSource();
             Connection conn=dsc.getConnection();
             int isolation = DataSourceElementBeanInfo.getTransactionIsolationMode(getTransactionIsolation());
             if (isolation >= 0 && conn.getTransactionIsolation() != isolation) {
@@ -368,7 +368,7 @@ public class DataSourceElement extends AbstractTestElement
             return conn;
         }
 
-        private BasicDataSource getConfiguredDatatSource() {
+        private BasicDataSource getConfiguredDataSource() {
             BasicDataSource dsc;
             if (sharedDSC != null){ // i.e. shared pool
                 dsc = sharedDSC;


[jmeter] 06/13: Rename variables

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 0988c06aac125a8a2ca5e48f96e12b1e5edbeee3
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:10:44 2019 +0100

    Rename variables
    
    + Replace label_resouce by label_resource
    + Replace resouces by resources
    + Replace resourcename by resourceName
    
    Part of #482 on github
---
 .../apache/jmeter/gui/util/JLabeledRadioI18N.java  | 30 +++++++++++-----------
 1 file changed, 15 insertions(+), 15 deletions(-)

diff --git a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/parser/RegexpHTMLParser.java b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/parser/RegexpHTMLParser.java
index 6f74230..f2499f8 100644
--- a/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/parser/RegexpHTMLParser.java
+++ b/src/protocol/http/src/main/java/org/apache/jmeter/protocol/http/parser/RegexpHTMLParser.java
@@ -37,8 +37,8 @@ import org.slf4j.LoggerFactory;
 /**
  * HtmlParser implementation using regular expressions.
  * <p>
- * This class will find RLs specified in the following ways (where <b>url</b>
- * represents the RL being found:
+ * This class will find URLs specified in the following ways (where <b>url</b>
+ * represents the URL being found:
  * <ul>
  * <li>&lt;img src=<b>url</b> ... &gt;
  * <li>&lt;script src=<b>url</b> ... &gt;
@@ -147,23 +147,19 @@ class RegexpHTMLParser extends HTMLParser {
                 MatchResult match = matcher.getMatch();
                 String s;
                 if (log.isDebugEnabled()) {
-                    log.debug("match groups " + match.groups() + " " + match.toString());
+                    log.debug("match groups {} {}", match.groups(), match);
                 }
                 // Check for a BASE HREF:
                 for (int g = 1; g <= NUM_BASE_GROUPS && g <= match.groups(); g++) {
                     s = match.group(g);
                     if (s != null) {
-                        if (log.isDebugEnabled()) {
-                            log.debug("new baseUrl: " + s + " - " + baseUrl.toString());
-                        }
+                        log.debug("new baseUrl: {} - {}", s, baseUrl);
                         try {
                             baseUrl = ConversionUtils.makeRelativeURL(baseUrl, s);
                         } catch (MalformedURLException e) {
                             // Doesn't even look like a URL?
                             // Maybe it isn't: Ignore the exception.
-                            if (log.isDebugEnabled()) {
-                                log.debug("Can't build base URL from RL " + s + " in page " + baseUrl, e);
-                            }
+                            log.debug("Can't build base URL from URL {} in page {}", s, baseUrl, e);
                         }
                     }
                 }
@@ -171,7 +167,7 @@ class RegexpHTMLParser extends HTMLParser {
                     s = match.group(g);
                     if (s != null) {
                         if (log.isDebugEnabled()) {
-                            log.debug("group " + g + " - " + match.group(g));
+                            log.debug("group {} - {}", g, match.group(g));
                         }
                         urls.addURL(s, baseUrl);
                     }


[jmeter] 03/13: Change function variable name displayJMeterPropterties by displayJMeterProperties

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit ff79a53c2dfa4fe941c2d4363dee687cb59d7304
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:02:33 2019 +0100

    Change function variable name displayJMeterPropterties by displayJMeterProperties
    
    Part of #482 on github
---
 .../src/main/java/org/apache/jmeter/extractor/DebugPostProcessor.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/components/src/main/java/org/apache/jmeter/extractor/DebugPostProcessor.java b/src/components/src/main/java/org/apache/jmeter/extractor/DebugPostProcessor.java
index 5d65ba4..825ced4 100644
--- a/src/components/src/main/java/org/apache/jmeter/extractor/DebugPostProcessor.java
+++ b/src/components/src/main/java/org/apache/jmeter/extractor/DebugPostProcessor.java
@@ -125,8 +125,8 @@ public class DebugPostProcessor extends AbstractTestElement implements PostProce
         return displayJMeterProperties;
     }
 
-    public void setDisplayJMeterProperties(boolean displayJMeterPropterties) {
-        this.displayJMeterProperties = displayJMeterPropterties;
+    public void setDisplayJMeterProperties(boolean displayJMeterProperties) {
+        this.displayJMeterProperties = displayJMeterProperties;
     }
 
     public boolean isDisplaySamplerProperties() {


[jmeter] 04/13: Change function variable name displayJMeterPropterties with displayJMeterProperties

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 039a56e3eb3df336ff7be26311bc7d316fc58a12
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:04:00 2019 +0100

    Change function variable name displayJMeterPropterties with displayJMeterProperties
    
    Part of #482 on github
---
 .../src/main/java/org/apache/jmeter/sampler/DebugSampler.java         | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/components/src/main/java/org/apache/jmeter/sampler/DebugSampler.java b/src/components/src/main/java/org/apache/jmeter/sampler/DebugSampler.java
index 36584dc..4fd6e97 100644
--- a/src/components/src/main/java/org/apache/jmeter/sampler/DebugSampler.java
+++ b/src/components/src/main/java/org/apache/jmeter/sampler/DebugSampler.java
@@ -109,8 +109,8 @@ public class DebugSampler extends AbstractSampler implements TestBean {
         return displayJMeterProperties;
     }
 
-    public void setDisplayJMeterProperties(boolean displayJMeterPropterties) {
-        this.displayJMeterProperties = displayJMeterPropterties;
+    public void setDisplayJMeterProperties(boolean displayJMeterProperties) {
+        this.displayJMeterProperties = displayJMeterProperties;
     }
 
     public boolean isDisplaySystemProperties() {


[jmeter] 08/13: Rename variable: replace ignoreResorces by ignoreResources

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 9b0c6563bad3a52dc44e883684f5fa56c278038f
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:13:25 2019 +0100

    Rename variable: replace ignoreResorces by ignoreResources
    
    Part of #482 on github
---
 src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java b/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java
index 02c1089..a4483f9 100644
--- a/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java
+++ b/src/core/src/main/java/org/apache/jmeter/util/JMeterUtils.java
@@ -120,7 +120,7 @@ public class JMeterUtils implements UnitTestManager {
     private static String jmDir; // JMeter Home directory (excludes trailing separator)
     private static String jmBin; // JMeter bin directory (excludes trailing separator)
 
-    private static volatile boolean ignoreResorces = false; // Special flag for use in debugging resources
+    private static volatile boolean ignoreResources = false; // Special flag for use in debugging resources
 
     private static final ThreadLocal<Perl5Matcher> localMatcher = ThreadLocal.withInitial(Perl5Matcher::new);
 
@@ -381,10 +381,10 @@ public class JMeterUtils implements UnitTestManager {
         }
         if ("ignoreResources".equals(loc.toString())){ // $NON-NLS-1$
             log.warn("Resource bundles will be ignored");
-            ignoreResorces = true;
+            ignoreResources = true;
             // Keep existing settings
         } else {
-            ignoreResorces = false;
+            ignoreResources = false;
             ResourceBundle resBund = ResourceBundle.getBundle("org.apache.jmeter.resources.messages", loc); // $NON-NLS-1$
             resources = resBund;
             locale = loc;
@@ -527,11 +527,11 @@ public class JMeterUtils implements UnitTestManager {
                 }
                 resString = defaultValue;
             }
-            if (ignoreResorces ){ // Special mode for debugging resource handling
+            if (ignoreResources ){ // Special mode for debugging resource handling
                 return "["+key+"]";
             }
         } catch (MissingResourceException mre) { // NOSONAR We handle correctly exception
-            if (ignoreResorces ){ // Special mode for debugging resource handling
+            if (ignoreResources ){ // Special mode for debugging resource handling
                 return "[?"+key+"?]";
             }
             if(defaultValue == null) {
diff --git a/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java b/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
index f4662e4..cffc441 100644
--- a/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
+++ b/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
@@ -56,13 +56,13 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
 
     /**
      *
      * @param label_resource text resource name for group label
      * @param item_resources list of resource names for individual buttons
      * @param selectedItem button to be selected (if not null)
      */
-    public JLabeledRadioI18N(String label_resource, String[] item_resources, String selectedItem) {
-        setLabel(label_resource);
-        init(item_resources, selectedItem);
+    public JLabeledRadioI18N(String labelResource, String[] itemResources, String selectedItem) {
+        setLabel(labelResource);
+        init(itemResources, selectedItem);
     }
 
     /**
@@ -176,11 +176,11 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
     /**
      * Set the group label from the resource name.
      *
      * @param label_resource The text to be looked up and set
      */
     @Override
-    public final void setLabel(String label_resource) {
-        this.mLabel.setText(JMeterUtils.getResString(label_resource));
+    public final void setLabel(String labelResource) {
+        this.mLabel.setText(JMeterUtils.getResString(labelResource));
     }
 
     /** {@inheritDoc} */


[jmeter] 11/13: Use a longer name for method variable

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 68df1dc765df5861721f672b6c911439b4f2e620
Author: Felix Schumacher <fe...@internetallee.de>
AuthorDate: Thu Aug 29 21:39:41 2019 +0200

    Use a longer name for method variable
    
    The old name was savee, which might have been
    an error, so try to be clearer about the
    name. It is the formatted result.
    
    Part of #482 on github
---
 src/core/src/main/java/org/apache/jmeter/save/CSVSaveService.java | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
@@ -56,13 +56,13 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
     /**
      *
-     * @param label_resource text resource name for group label
-     * @param item_resources list of resource names for individual buttons
+     * @param labelResource text resource name for group label
+     * @param itemResources list of resource names for individual buttons
      * @param selectedItem button to be selected (if not null)
      */
@@ -176,11 +176,11 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
      * Set the group label from the resource name.
      *
-     * @param label_resource The text to be looked up and set
+     * @param labelResource The text to be looked up and set
      */
     @Override

diff --git a/src/core/src/main/java/org/apache/jmeter/config/gui/ArgumentsPanel.java b/src/core/src/main/java/org/apache/jmeter/config/gui/ArgumentsPanel.java
index 5810083..eaaf228 100644
--- a/src/core/src/main/java/org/apache/jmeter/config/gui/ArgumentsPanel.java
+++ b/src/core/src/main/java/org/apache/jmeter/config/gui/ArgumentsPanel.java
@@ -423,17 +423,17 @@ public class ArgumentsPanel extends AbstractConfigGui implements ActionListener
 
     /**
      * ensure that a row is visible in the viewport
      * @param rowIndx row index
      */
-    private void scrollToRowIfNotVisible(int rowIndx) {
+    private void scrollToRowIfNotVisible(int rowIndex) {
         if(table.getParent() instanceof JViewport) {
             Rectangle visibleRect = table.getVisibleRect();
             final int cellIndex = 0;
-            Rectangle cellRect = table.getCellRect(rowIndx, cellIndex, false);
+            Rectangle cellRect = table.getCellRect(rowIndex, cellIndex, false);
             if (visibleRect.y > cellRect.y) {
                 table.scrollRectToVisible(cellRect);
             } else {
-                Rectangle rect2 = table.getCellRect(rowIndx + getNumberOfVisibleRows(table), cellIndex, true);
+                Rectangle rect2 = table.getCellRect(rowIndex + getNumberOfVisibleRows(table), cellIndex, true);
                 int width = rect2.y - cellRect.y;
                 table.scrollRectToVisible(new Rectangle(cellRect.x, cellRect.y, cellRect.width, cellRect.height + width));
             }


[jmeter] 09/13: Rename function name: Replace getConfiguredDatatSource() by getConfiguredDataSource()

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit c73951df00274700d63a0846d7290125da04b823
Author: Anass BENOMAR <an...@gmail.com>
AuthorDate: Mon Aug 26 18:15:41 2019 +0100

    Rename function name: Replace getConfiguredDatatSource() by getConfiguredDataSource()
    
    Part of #482 on github
---
 .../org/apache/jmeter/protocol/jdbc/config/DataSourceElement.java   | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
@@ -423,17 +423,17 @@ public class ArgumentsPanel extends AbstractConfigGui implements ActionListener
     /**
      * ensure that a row is visible in the viewport
-     * @param rowIndx row index
+     * @param rowIndex row index
      */

diff --git a/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java b/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
index 451569a..f4662e4 100644
--- a/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
+++ b/src/core/src/main/java/org/apache/jmeter/gui/util/JLabeledRadioI18N.java
@@ -56,12 +56,12 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
 
     /**
      *
      * @param label_resouce text resource name for group label
      * @param item_resources list of resource names for individual buttons
      * @param selectedItem button to be selected (if not null)
      */
-    public JLabeledRadioI18N(String label_resouce, String[] item_resources, String selectedItem) {
-        setLabel(label_resouce);
+    public JLabeledRadioI18N(String label_resource, String[] item_resources, String selectedItem) {
+        setLabel(label_resource);
         init(item_resources, selectedItem);
     }
 
@@ -80,13 +80,13 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
      * The resource name is used as the action command for the button model,
      * and the resource value is used to set the button label.
      *
-     * @param resouces list of resource names
+     * @param resources list of resource names
      * @param selected initially selected resource (if not null)
      *
      */
-    private void init(String[] resouces, String selected) {
+    private void init(String[] resources, String selected) {
         this.add(mLabel);
-        initButtonGroup(resouces, selected);
+        initButtonGroup(resources, selected);
     }
 
     /**
@@ -96,12 +96,12 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
      * The resource name is used as the action command for the button model,
      * and the resource value is used to set the button label.
      *
-     * @param resouces list of resource names
+     * @param resources list of resource names
      * @param selected initially selected resource (if not null)
      *
      */
-    private void initButtonGroup(String[] resouces, String selected) {
-        for (String resource : resouces) {
+    private void initButtonGroup(String[] resources, String selected) {
+        for (String resource : resources) {
             JRadioButton btn = new JRadioButton(JMeterUtils.getResString(resource));
             btn.setActionCommand(resource);
             btn.addActionListener(this);
@@ -123,11 +123,11 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
      * The resource name is used as the action command for the button model,
      * and the resource value is used to set the button label.
      *
-     * @param resouces list of resource names
+     * @param resources list of resource names
      * @param selected initially selected resource (if not null)
      *
      */
-    public void resetButtons(String[] resouces, String selected) {
+    public void resetButtons(String[] resources, String selected) {
         Enumeration<AbstractButton> buttons = bGroup.getElements();
         List<AbstractButton> buttonsToRemove = new ArrayList<>(this.bGroup.getButtonCount());
         while (buttons.hasMoreElements()) {
@@ -142,7 +142,7 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
         for (AbstractButton abstractButton : buttonsToRemove) {
             this.remove(abstractButton);
         }
-        initButtonGroup(resouces, selected);
+        initButtonGroup(resources, selected);
     }
 
     /**
@@ -158,14 +158,14 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
      * The implementation will iterate through the radio buttons and find the
      * match. It then sets it to selected and sets all other radio buttons as
      * not selected.
-     * @param resourcename name of resource whose button is to be selected
+     * @param resourceName name of resource whose button is to be selected
      */
     @Override
-    public void setText(String resourcename) {
+    public void setText(String resourceName) {
         Enumeration<AbstractButton> en = this.bGroup.getElements();
         while (en.hasMoreElements()) {
             ButtonModel model = en.nextElement().getModel();
-            if (model.getActionCommand().equals(resourcename)) {
+            if (model.getActionCommand().equals(resourceName)) {
                 this.bGroup.setSelected(model, true);
             } else {
                 this.bGroup.setSelected(model, false);


[jmeter] 01/13: Use string formats in log messages and add a missing U to URL

Posted by fs...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

fschumacher pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/jmeter.git

commit 6e858d8eb132ca650a3adcd423d355b1540c4396
Author: Felix Schumacher <fe...@internetallee.de>
AuthorDate: Wed Aug 28 20:30:20 2019 +0200

    Use string formats in log messages and add a missing U to URL
---
 .../jmeter/protocol/http/parser/RegexpHTMLParser.java    | 16 ++++++----------
 1 file changed, 6 insertions(+), 10 deletions(-)
@@ -56,12 +56,12 @@ public class JLabeledRadioI18N extends JPanel implements JLabeledField, ActionLi
     /**
      *
-     * @param label_resouce text resource name for group label
+     * @param label_resource text resource name for group label
      * @param item_resources list of resource names for individual buttons
      * @param selectedItem button to be selected (if not null)
